@@ -877,13 +877,12 @@ void do_init_repos( Zypper & zypper )
         // user
         catch ( const Exception & ex )
         {
+          ZYPP_CAUGHT( ex );
           MIL << "We're running as non-root, skipping refresh of " << repo.alias() << endl;
-
-          //./src/Config.cc:    std::cerr << e.asUserHistory() << endl;
-          zypper.out().error( ex, "Problem", "hint" );
-
-
-          zypper.out().info( str::Format(_( "Repository '%s' is out-of-date. You can run 'zypper refresh' as root to update it.")) % repo.asUserString() );
+          // bsc#1235636: Asks to suppress reporting the Exception (usually: No permission to
+          // write repository cache), because it scares. This was was indeed the legacy behavior:
+          // SUPPRESS: zypper.out().error( ex, "Problem" );
+          zypper.out().notePar( 4, str::Format(_( "Repository '%s' is out-of-date. You can run 'zypper refresh' as root to update it.")) % repo.asUserString() );
         }
       }
     }
@@ -1778,11 +1777,15 @@ void load_repo_resolvables( Zypper & zypper )
     try
     {
       bool error = false;
+
       // if there is no metadata locally
       if ( manager.metadataStatus(repo).empty() )
       {
-        zypper.out().info( str::Format(_("Retrieving repository '%s' data...")) % repo.name() );
-        error = refresh_raw_metadata( zypper, repo, false );
+        if ( geteuid() == 0 ) {
+          zypper.out().info( str::Format(_("Retrieving repository '%s' data...")) % repo.name() );
+          error = refresh_raw_metadata( zypper, repo, false );
+        }
+        // else: as non-root user we'll see whether a usable solv cache exists ....
       }
 
       if ( !error && !manager.isCached(repo) )
